@@ -1,10 +1,13 @@
 import logging
 
 import click
-from plugin_sdk_automation.handlers import DockerHandler
 from rich.logging import RichHandler
 from rich.traceback import install
 
+from .handlers import DockerHandler
+from .handlers.props_handler import PropsHandler
+
+
 install()
 
 
@@ -36,6 +39,12 @@ def build(directory: str, python_version: str):
     d.build()
 
 
+@cli.command()
+def gen_props():
+    p = PropsHandler(log=log)
+    p.run()
+
+
 def main():
     cli()
 
